@@ -1,9 +1,6 @@
 from typing import Optional
 
-from prefect import task
 
-
-@task
 def get_location_voxels(location: dict, region: Optional[str] = None) -> list[tuple[int, int, int]]:
     voxels = [
         voxel
