@@ -1,8 +1,6 @@
 import pandas as pd
-from prefect import task
 
 
-@task
 def merge_parsed_results(*results: pd.DataFrame) -> pd.DataFrame:
     for result in results:
         result.set_index(["ID", "TICK"], inplace=True)
