@@ -1,9 +1,8 @@
 import json
 import tarfile
-from typing import List, Union
+from typing import Union
 
 import pandas as pd
-from prefect import task
 
 CELLS_COLUMNS = [
     "ID",
@@ -18,9 +17,8 @@ CELLS_COLUMNS = [
 ]
 
 
-@task
 def parse_cells_file(tar: tarfile.TarFile, regions: list[str]) -> pd.DataFrame:
-    all_cells: List[List[Union[str, int]]] = []
+    all_cells: list[list[Union[str, int]]] = []
 
     for member in tar.getmembers():
         timepoint = int(member.name.replace(".CELLS.json", "").split("_")[-1])
